@@ -6,6 +6,7 @@ import threading
 import time
 import sys
 import tarfile
+import httplib
 
 class App:
     def __init__(self):
@@ -109,10 +110,10 @@ class App:
         menu_item.set_callback(self.show_import_profile)
         menu.add_item(menu_item)
 
-        # menu_item = interface.MenuItem()
-        # menu_item.set_label('Import Profile URI')
-        # menu_item.set_callback(self.show_import_profile_uri)
-        # menu.add_item(menu_item)
+        menu_item = interface.MenuItem()
+        menu_item.set_label('Import Profile URI')
+        menu_item.set_callback(self.show_import_profile_uri)
+        menu.add_item(menu_item)
 
         menu_item = interface.MenuItem()
         menu_item.set_label('About')
@@ -266,6 +267,17 @@ class App:
         dialog.run()
         dialog.destroy()
 
+    def show_import_profile_error(self, message):
+        dialog = interface.MessageDialog()
+        dialog.set_type(MESSAGE_ERROR)
+        dialog.set_buttons(BUTTONS_OK)
+        dialog.set_title(APP_NAME_FORMATED)
+        dialog.set_icon(utils.get_logo())
+        dialog.set_message('Failed to import profile:')
+        dialog.set_message_secondary(str(message).capitalize())
+        dialog.run()
+        dialog.destroy()
+
     def show_import_profile(self):
         dialog = interface.FileChooserDialog()
         dialog.set_title(APP_NAME_FORMATED)
@@ -277,15 +289,18 @@ class App:
         response = dialog.run()
         dialog.destroy()
         if response:
-            if os.path.splitext(response)[1] == '.tar':
-                tar = tarfile.open(response)
-                for member in tar:
-                    profile = Profile.get_profile()
-                    profile.write_profile(tar.extractfile(member).read())
-            else:
-                with open(response, 'r') as profile_file:
-                    profile = Profile.get_profile()
-                    profile.write_profile(profile_file.read())
+            try:
+                if os.path.splitext(response)[1] == '.tar':
+                    tar = tarfile.open(response)
+                    for member in tar:
+                        profile = Profile.get_profile()
+                        profile.write_profile(tar.extractfile(member).read())
+                else:
+                    with open(response, 'r') as profile_file:
+                        profile = Profile.get_profile()
+                        profile.write_profile(profile_file.read())
+            except Exception as exception:
+                self.show_import_profile_error(exception)
             self.update_menu()
 
     def show_import_profile_uri(self):
@@ -299,6 +314,37 @@ class App:
         response = dialog.run()
         dialog.destroy()
         if response:
+            url = response
+            if url[:2] == 'pt':
+                url = url.replace('pt', 'http', 1)
+            if url[:4] != 'http':
+                url = 'http://' + url
+            try:
+                for i in xrange(2):
+                    try:
+                        response = utils.request.get(url)
+                        if response.status_code != 400:
+                            break
+                    except httplib.HTTPException:
+                        if i == 1:
+                            raise
+                    if url[:5] == 'https':
+                        url = url.replace('https', 'http', 1)
+                    else:
+                        url = url.replace('http', 'https', 1)
+                if response.status_code == 200:
+                    pass
+                elif response.status_code == 404:
+                    raise Exception('Key link is not valid')
+                else:
+                    raise Exception('Pritunl server returned error code %s' % (response.status_code))
+                data = response.json()
+
+                for key in data:
+                    profile = Profile.get_profile()
+                    profile.write_profile(data[key])
+            except Exception as exception:
+                self.show_import_profile_error(exception)
             self.update_menu()
 
     def autostart(self):
