@@ -19,13 +19,9 @@ debuild -S
 sed -i -e 's/0ubuntu1/0ubuntu1~precise/g' debian/changelog
 sed -i -e 's/trusty;/precise;/g' debian/changelog
 debuild -S
-sed -i -e 's/0ubuntu1~precise/0ubuntu1~saucy/g' debian/changelog
-sed -i -e 's/precise;/saucy;/g' debian/changelog
-debuild -S
 
 cd ..
 
 echo '\n\nRUN COMMANDS BELOW TO UPLOAD:'
 echo 'sudo dput ppa:pritunl/ppa ../build/debian/pritunl-client_'$VERSION'-0ubuntu1_source.changes'
 echo 'sudo dput ppa:pritunl/ppa ../build/debian/pritunl-client_'$VERSION'-0ubuntu1~precise_source.changes'
-echo 'sudo dput ppa:pritunl/ppa ../build/debian/pritunl-client_'$VERSION'-0ubuntu1~saucy_source.changes'
