@@ -8,7 +8,6 @@ parser.add_option('--version', action='store_true', help='Print version')
 
 if options.version:
     print '%s v%s' % (pritunl.__title__, pritunl.__version__)
-    sys.exit(0)
-
-app = pritunl_client.app.App()
-app.main()
+else:
+    app = pritunl_client.app.App()
+    app.main()
